searchData={"items":[{"type":"module","title":"OpenTelemetryDecorator","doc":"<!-- INCLUDE -->\nA function decorator for OpenTelemetry traces.","ref":"OpenTelemetryDecorator.html"},{"type":"module","title":"Installation - OpenTelemetryDecorator","doc":"Add `open_telemetry_decorator` to your list of dependencies in `mix.exs`. We include the `opentelemetry_api` package, but you'll need to add `opentelemetry` yourself in order to report spans and traces.\n\n```elixir\ndef deps do\n  [\n    {:opentelemetry, \"~> 1.4\"},\n    {:opentelemetry_exporter, \"~> 1.7\"},\n    {:open_telemetry_decorator, \"~> 1.5\"}\n  ]\nend\n```\n\nThen follow the directions for the exporter of your choice to send traces to to zipkin, honeycomb, etc.\nhttps://github.com/open-telemetry/opentelemetry-erlang/tree/main/apps/opentelemetry_zipkin","ref":"OpenTelemetryDecorator.html#module-installation"},{"type":"module","title":"Honeycomb Example - OpenTelemetryDecorator","doc":"`config/runtime.exs`\n```elixir\napi_key = System.fetch_env!(\"HONEYCOMB_KEY\")\n\nconfig :opentelemetry_exporter,\n  otlp_endpoint: \"https://api.honeycomb.io:443\",\n  otlp_headers: [{\"x-honeycomb-team\", api_key}]\n```","ref":"OpenTelemetryDecorator.html#module-honeycomb-example"},{"type":"module","title":"Usage - OpenTelemetryDecorator","doc":"Add `use OpenTelemetryDecorator` to the module, and decorate any methods you want to trace with `@decorate with_span(\"span name\")`.\n\nThe `with_span` decorator will automatically wrap the decorated function in an opentelemetry span with the provided name.\n\n```elixir\ndefmodule MyApp.Worker do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"worker.do_work\")\n  def do_work(arg1, arg2) do\n    ...doing work\n  end\nend\n```","ref":"OpenTelemetryDecorator.html#module-usage"},{"type":"module","title":"Span Attributes - OpenTelemetryDecorator","doc":"The `with_span` decorator allows you to specify an `include` option which gives you more flexibility with what you can include in the span attributes. Omitting the `include` option with `with_span` means no attributes will be added to the span by the decorator.\n\n```elixir\ndefmodule MyApp.Worker do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"worker.do_work\", include: [:arg1, :arg2])\n  def do_work(arg1, arg2) do\n    # ...doing work\n  end\nend\n```\n\nThe O11y module includes a helper for setting additional attributes outside of the `include` option. Attributes added in either a `set` call or in the `include` that are not [primitive OTLP values](https://github.com/open-telemetry/opentelemetry-erlang/blob/main/apps/opentelemetry_api/src/opentelemetry.erl#L111) will be converted to strings with `Kernel.inspect/1`.\n\n```elixir\ndefmodule MyApp.Worker do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"worker.do_work\")\n  def do_work(arg1, arg2) do\n    O11y.set_attributes(arg1: arg1, arg2: arg2)\n    # ...doing work\n    Attributes.set_attribute(:output, \"something\")\n  end\nend\n```\n\nThe decorator uses a macro to insert code into your function at compile time to wrap the body in a new span and link it to the currently active span. In the example above, the `do_work` method would become something like this:\n\n```elixir\ndefmodule MyApp.Worker do\n  require OpenTelemetry.Tracer, as: Tracer\n\n  def do_work(arg1, arg2) do\n    Tracer.with_span \"my_app.worker.do_work\" do\n      # ...doing work\n      Tracer.set_attributes(arg1: arg1, arg2: arg2)\n    end\n  end\nend\n```","ref":"OpenTelemetryDecorator.html#module-span-attributes"},{"type":"module","title":"Configuration - OpenTelemetryDecorator","doc":"","ref":"OpenTelemetryDecorator.html#module-configuration"},{"type":"module","title":"Prefixing Span Attributes - OpenTelemetryDecorator","doc":"Honeycomb suggests that you [namespace custom fields](https://docs.honeycomb.io/getting-data-in/data-best-practices/#namespace-custom-fields), specifically prefixing manual instrumentation with `app`\n\n✳️ You can now set this in the underlying `o11y` library with the `attribute_namespace` option ✳️\n\n```elixir\nconfig :o11y, :attribute_namespace, \"app\"\n```\n\n⚠️ You can still configure it with the `attr_prefix` option in `config/config.exs`, but that will be deprecated in a future release. ⚠️\n\n```elixir\nconfig :open_telemetry_decorator, attr_prefix: \"app.\"\n```","ref":"OpenTelemetryDecorator.html#module-prefixing-span-attributes"},{"type":"module","title":"Changing the join character for nested attributes - OpenTelemetryDecorator","doc":"⚠️ This configuration option is no longer available ⚠️","ref":"OpenTelemetryDecorator.html#module-changing-the-join-character-for-nested-attributes"},{"type":"module","title":"Additional Examples - OpenTelemetryDecorator","doc":"You can provide span attributes by specifying a list of variable names as atoms.\n\nThis list can include...\n\nAny variables (in the top level closure) available when the function exits.\nNote that variables declared as part of an `if`, `case`, `cond`, or `with` block are in a separate scope so NOT available for `include` attributes.\n\n```elixir\ndefmodule MyApp.Math do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"my_app.math.add\", include: [:a, :b, :sum])\n  def add(a, b) do\n    sum = a + b\n    {:ok, sum}\n  end\nend\n```\n\nThe result of the function by including the atom `:result`:\n\n```elixir\ndefmodule MyApp.Math do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"my_app.math.add\", include: [:result])\n  def add(a, b) do\n    {:ok, a + b}\n  end\nend\n```\n\nStructs will be converted to maps and included in the span attributes. You can specify which fields to include with the `@derive` attribute provided by `O11y`.\n\n```elixir\ndefmodule User do\n  use OpenTelemetryDecorator\n\n  @derive {O11y.SpanAttributes, only: [:id, :name]}\n  defstruct [:id, :name, :email, :password]\n\n  @decorate with_span(\"user.create\", include: [:user])\n  def create(user) do\n    {:ok, user}\n  end\nend\n```","ref":"OpenTelemetryDecorator.html#module-additional-examples"},{"type":"module","title":"Development - OpenTelemetryDecorator","doc":"`make check` before you commit! If you'd prefer to do it manually:\n\n* `mix do deps.get, deps.unlock --unused, deps.clean --unused` if you change dependencies\n* `mix compile --warnings-as-errors` for a stricter compile\n* `mix coveralls.html` to check for test coverage\n* `mix credo` to suggest more idiomatic style for your code\n* `mix dialyzer` to find problems typing might reveal… albeit *slowly*\n* `mix docs` to generate documentation","ref":"OpenTelemetryDecorator.html#module-development"},{"type":"macro","title":"OpenTelemetryDecorator.trace/1","doc":"","ref":"OpenTelemetryDecorator.html#trace/1"},{"type":"macro","title":"OpenTelemetryDecorator.trace/2","doc":"","ref":"OpenTelemetryDecorator.html#trace/2"},{"type":"function","title":"OpenTelemetryDecorator.trace/4","doc":"","ref":"OpenTelemetryDecorator.html#trace/4"},{"type":"macro","title":"OpenTelemetryDecorator.with_span/1","doc":"","ref":"OpenTelemetryDecorator.html#with_span/1"},{"type":"macro","title":"OpenTelemetryDecorator.with_span/2","doc":"","ref":"OpenTelemetryDecorator.html#with_span/2"},{"type":"function","title":"OpenTelemetryDecorator.with_span/4","doc":"Decorate a function to add to or create an OpenTelemetry trace with a named span.\n\nYou can provide span attributes by specifying a list of variable names as atoms.\nThis list can include:\n\n- any variables (in the top level closure) available when the function exits,\n- the result of the function by including the atom `:result`,\n- map/struct properties using nested lists of atoms.\n\n```elixir\ndefmodule MyApp.Worker do\n  use OpenTelemetryDecorator\n\n  @decorate with_span(\"my_app.worker.do_work\", include: [:arg1, [:arg2, :count], :total, :result])\n  def do_work(arg1, arg2) do\n    total = arg1.count + arg2.count\n    {:ok, total}\n  end\nend\n```","ref":"OpenTelemetryDecorator.html#with_span/4"},{"type":"module","title":"OpenTelemetryDecorator.Attributes","doc":"Wrapper to switch between v1 and v2","ref":"OpenTelemetryDecorator.Attributes.html"},{"type":"function","title":"OpenTelemetryDecorator.Attributes.attribute_prefix/0","doc":"","ref":"OpenTelemetryDecorator.Attributes.html#attribute_prefix/0"},{"type":"function","title":"OpenTelemetryDecorator.Attributes.get/2","doc":"","ref":"OpenTelemetryDecorator.Attributes.html#get/2"},{"type":"function","title":"OpenTelemetryDecorator.Attributes.set/1","doc":"","ref":"OpenTelemetryDecorator.Attributes.html#set/1"},{"type":"function","title":"OpenTelemetryDecorator.Attributes.set/2","doc":"","ref":"OpenTelemetryDecorator.Attributes.html#set/2"},{"type":"function","title":"OpenTelemetryDecorator.Attributes.set/3","doc":"","ref":"OpenTelemetryDecorator.Attributes.html#set/3"},{"type":"module","title":"OpenTelemetryDecorator.AttributesV1","doc":"","ref":"OpenTelemetryDecorator.AttributesV1.html"},{"type":"function","title":"OpenTelemetryDecorator.AttributesV1.get/2","doc":"","ref":"OpenTelemetryDecorator.AttributesV1.html#get/2"},{"type":"macro","title":"OpenTelemetryDecorator.AttributesV1.is_otlp_value/1","doc":"","ref":"OpenTelemetryDecorator.AttributesV1.html#is_otlp_value/1"},{"type":"function","title":"OpenTelemetryDecorator.AttributesV1.set/1","doc":"","ref":"OpenTelemetryDecorator.AttributesV1.html#set/1"},{"type":"function","title":"OpenTelemetryDecorator.AttributesV1.set/2","doc":"","ref":"OpenTelemetryDecorator.AttributesV1.html#set/2"},{"type":"function","title":"OpenTelemetryDecorator.AttributesV1.set/3","doc":"","ref":"OpenTelemetryDecorator.AttributesV1.html#set/3"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,49]}}